[llvm-commits] CVS: llvm/include/llvm/Target/TargetAsmInfo.h

Anton Korobeynikov asl at math.spbu.ru
Sat May 5 02:05:22 PDT 2007



Changes in directory llvm/include/llvm/Target:

TargetAsmInfo.h updated: 1.32 -> 1.33
---
Log message:

Emit sections/directives in the proper order. This fixes PR1376: http://llvm.org/PR1376 . Also, 
some small cleanup was made.


---
Diffs of the changes:  (+12 -4)

 TargetAsmInfo.h |   16 ++++++++++++----
 1 files changed, 12 insertions(+), 4 deletions(-)


Index: llvm/include/llvm/Target/TargetAsmInfo.h
diff -u llvm/include/llvm/Target/TargetAsmInfo.h:1.32 llvm/include/llvm/Target/TargetAsmInfo.h:1.33
--- llvm/include/llvm/Target/TargetAsmInfo.h:1.32	Tue May  1 17:23:12 2007
+++ llvm/include/llvm/Target/TargetAsmInfo.h	Sat May  5 04:04:50 2007
@@ -282,8 +282,13 @@
     /// HasDotFile - True if target asm supports .file directives.
     ///
     bool HasDotFile; // Defaults to false.
-    
-    /// SupportsExceptionHandling - True if target supports exception handling.
+
+    /// SupportsDebugInformation - True if target supports emission of debugging
+    /// information.
+    bool SupportsDebugInformation;
+        
+    /// SupportsExceptionHandling - True if target supports
+    /// exception handling.
     ///
     bool SupportsExceptionHandling; // Defaults to false.
     
@@ -549,10 +554,13 @@
     bool hasDotFile() const {
       return HasDotFile;
     }
-    bool getSupportsExceptionHandling() const {
+    bool doesSupportDebugInformation() const {
+      return SupportsDebugInformation;
+    }
+    bool doesSupportExceptionHandling() const {
       return SupportsExceptionHandling;
     }
-    bool getDwarfRequiresFrameSection() const {
+    bool doesDwarfRequireFrameSection() const {
       return DwarfRequiresFrameSection;
     }
     const char *getDwarfSectionOffsetDirective() const {






More information about the llvm-commits mailing list